package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: May 16, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type EngineOpts struct {
ShowFile bool
ShowIndex bool
}
EngineOpts controls optional engine behaviors.
type Result struct {
Objects []any
}
Result holds the output of a query execution.
Execute parses the query string and applies the query pipeline to the objects.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.